flutter_monetization_kit library

Classes

AdaptiveBanner
AdRegistry
AdsSettings
AdUtils
AppOpenAdCallbacks
AppOpenObserver
AppOpenObserver listens to app lifecycle changes and automatically requests an App Open Ad to show when the app resumes.
AppTrackingTransparency
BannerAdCallbacks
BannerAdWidget
BannerType
Defines the different banner formats supported by the package
CollapsibleBanner
For Collapsible Banners (Top or Bottom)
CustomHeightBanner
For Custom Height only
CustomSizeBanner
For Custom Height and Width
GoogleConsentManager
A professional Google Consent Manager that utilizes the User Messaging Platform (UMP) SDK to handle app user consent requests, specifically for GDPR compliance.
InterstitialAdCallbacks
LargeBanner
MonetizationKit
NativeAdCallbacks
NativeAdShimmerStyle
NativeAdStyle
NativeWidget
RectangleBanner
RewardedAdCallbacks
RewardedInterAdCallbacks
StandardBanner

Extensions

AppTrackingStatusExtension on String
Extension to convert string from native iOS to enum
BannerTypeExtension on BannerType